@@ -10,7 +10,7 @@ from nerualpha.session.neruSession import NeruSession
 #interface
 class INeru(ABC):
     @abstractmethod
-    def createSession(self):
+    def createSession(self,ttl):
         pass
     @abstractmethod
     def createSessionWithId(self,id):
@@ -19,9 +19,6 @@ class INeru(ABC):
     def getSessionById(self,id):
         pass
     @abstractmethod
-    def Router(self):
-        pass
-    @abstractmethod
     def getAppUrl(self):
         pass
     @abstractmethod
