@@ -11,10 +11,11 @@ from nerualpha.providers.logger.ILogContext import ILogContext
 from nerualpha.providers.logger.ILogger import ILogger
 from nerualpha.providers.logger.logAction import LogAction
 from nerualpha.providers.logger.sourceTypes import SourceTypes
+from nerualpha.services.config.urlObject import UrlObject
 
 @dataclass
 class Logger(ILogger):
-    url: str
+    url: UrlObject
     session: ISession
     bridge: IBridge
     config: IConfig
