@@ -2,9 +2,9 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.messages.contracts.ISendImagePayload import ISendImagePayload
-from src.providers.messages.contracts.IMessageContact import IMessageContact
-from src.providers.messages.contracts.ISendImageContent import ISendImageContent
+from nerualpha.providers.messages.contracts.ISendImagePayload import ISendImagePayload
+from nerualpha.providers.messages.contracts.IMessageContact import IMessageContact
+from nerualpha.providers.messages.contracts.ISendImageContent import ISendImageContent
 
 @dataclass
 class SendImagePayload(ISendImagePayload):
