@@ -7,10 +7,10 @@ from nerualpha.providers.messages.contracts.IWhatsappTextMessage import IWhatsap
 @dataclass
 class WhatsappTextMessage(IWhatsappTextMessage):
     to: str
-    message_type: str
     from_: str
-    channel: str
     text: str
+    channel: str = field(default = "whatsapp")
+    message_type: str = field(default = "text")
     def __init__(self):
         pass
     def reprJSON(self):
