@@ -5,7 +5,7 @@ from abc import ABC, abstractmethod
 from nerualpha.providers.scheduler.contracts.ISchedulePayload import ISchedulePayload
 
 @dataclass
-class SchedulePayload(ISchedulePayload):
+class SchedulerPayload(ISchedulePayload):
     id: str
     def __init__(self,id):
         self.id = id
