@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.state.IStateCommand import IStateCommand
+from nerualpha.providers.state.IStateCommand import IStateCommand
 
 @dataclass
 class StateCommand(IStateCommand):
