@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IChannel import IChannel
-from src.providers.voice.contracts.IChannelEndpoint import IChannelEndpoint
+from nerualpha.providers.voice.contracts.IChannel import IChannel
+from nerualpha.providers.voice.contracts.IChannelEndpoint import IChannelEndpoint
 
 @dataclass
 class Channel(IChannel):
