@@ -2,8 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.providers.voice.contracts.IChannelSIPEndpoint import IChannelSIPEndpoint
-from src.providers.voice.csChannelTypes import CSChannelTypes
+from nerualpha.providers.voice.contracts.IChannelSIPEndpoint import IChannelSIPEndpoint
+from nerualpha.providers.voice.csChannelTypes import CSChannelTypes
 
 @dataclass
 class ChannelSIPEndpoint(IChannelSIPEndpoint):
