@@ -2,12 +2,21 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.providers.voice.contracts.ICreateConversationResponse import ICreateConversationResponse
+from nerualpha.providers.voice.contracts.selfLink import SelfLink
+from nerualpha.providers.voice.contracts.conversationTimestamp import ConversationTimestamp
+from nerualpha.providers.voice.contracts.responseProperties import ResponseProperties
 
 @dataclass
-class CreateConversationResponse(ICreateConversationResponse):
-    href: str
+class CreateConversationResponse:
+    sequence_number: int
+    properties: ResponseProperties
+    state: str
+    name: str
+    timestamp: ConversationTimestamp
+    _links: SelfLink
     id: str
+    display_name: str = None
+    image_url: str = None
     def __init__(self):
         pass
     def reprJSON(self):
