@@ -8,6 +8,9 @@ from nerualpha.providers.voice.contracts.IUser import IUser
 class User(IUser):
     id: str = None
     name: str = None
+    display_name: str = None
+    image_url: str = None
+    custom_data: object = None
     def __init__(self):
         pass
     def reprJSON(self):
