@@ -2,14 +2,14 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
+from nerualpha.providers.voice.contracts.IChannelPhoneEndpoint import IChannelPhoneEndpoint
 from nerualpha.providers.voice.contracts.IVapiCreateCallPayload import IVapiCreateCallPayload
-from nerualpha.providers.voice.contracts.IPhoneContact import IPhoneContact
 
 @dataclass
 class VapiCreateCallPayload(IVapiCreateCallPayload):
     ncco: List[Dict[str,object]]
-    to: List[IPhoneContact]
-    from_: IPhoneContact
+    to: List[IChannelPhoneEndpoint]
+    from_: IChannelPhoneEndpoint
     def __init__(self,from_,to,ncco):
         self.from_ = from_
         self.to = to
