@@ -8,7 +8,7 @@ from nerualpha.session.IWrappedCallback import IWrappedCallback
 @dataclass
 class VapiEventCallBackPayload(IVapiEventCallBackPayload):
     callback: IWrappedCallback
-    vapiId: str = None
+    vapiID: str = None
     conversationID: str = None
     def __init__(self):
         pass
