@@ -2,11 +2,11 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from nerualpha.request.IRequestHeaders import IRequestHeaders
+from nerualpha.services.config.urlObject import UrlObject
 
 
 #interface
 class ICommandService(ABC):
     @abstractmethod
-    def executeCommand(self,url,data = None,headers = None):
+    def executeCommand(self,url,method,data = None,headers = None):
         pass
