@@ -3,6 +3,7 @@ from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
 from nerualpha.IBridge import IBridge
+from nerualpha.services.config.urlObject import UrlObject
 
 
 #interface
@@ -19,5 +20,5 @@ class IConfig(ABC):
     assetUrl:str
     namespace:str
     @abstractmethod
-    def getExecutionUrl(self,func):
+    def getExecutionUrl(self,func,pathname = None):
         pass
