@@ -2,7 +2,7 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
-from src.webhookEvents.viber.IViberEvent import IViberEvent
+from nerualpha.webhookEvents.viber.IViberEvent import IViberEvent
 
 @dataclass
 class ViberEvent(IViberEvent):
