@@ -2,6 +2,8 @@ from dataclasses import dataclass, field
 from typing import Dict, List, Generic, TypeVar
 from abc import ABC, abstractmethod
 
+from nerualpha.webhookEvents.whatsapp.IMessageEventContext import IMessageEventContext
+from nerualpha.webhookEvents.whatsapp.IProfileName import IProfileName
 from nerualpha.webhookEvents.whatsapp.IWhatsappUnsupportedEvent import IWhatsappUnsupportedEvent
 
 @dataclass
@@ -9,9 +11,12 @@ class WhatsappUnsupportedEvent(IWhatsappUnsupportedEvent):
     to: str
     timestamp: str
     message_uuid: str
-    message_type: str
     from_: str
     channel: str
+    message_type: str
+    profile: IProfileName = None
+    context: IMessageEventContext = None
+    provider_message: str = None
     def __init__(self):
         pass
     def reprJSON(self):
